@@ -30,11 +30,12 @@
 #include <config.h>
 
 #include "rcsid.h"
-RCSID("$Id: getdef.c,v 1.18 2003/05/12 02:40:08 kloczek Exp $")
+RCSID("$Id: getdef.c,v 1.20 2005/01/20 12:43:05 kloczek Exp $")
 
 #include "prototypes.h"
 #include "defines.h"
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include "getdef.h"
 
@@ -129,8 +130,6 @@ static struct itemdef def_table[] = {
 static char def_fname[] = LOGINDEFS;	/* login config defs file	*/
 static int def_loaded = 0;		/* are defs already loaded?	*/
 
-extern long strtol();
-
 /* local function prototypes */
 static struct itemdef *def_find(const char *);
 static void def_load(void);
@@ -349,7 +348,7 @@ def_load(void)
 	if ((fp = fopen(def_fname, "r")) == NULL) {
 		SYSLOG((LOG_CRIT, "cannot open login definitions %s [%m]",
 			def_fname));
-		return;
+		exit(1);
 	}
 
 	/*
@@ -392,6 +391,13 @@ def_load(void)
 		 */
 		putdef_str(name, value);
 	}
+
+	if (ferror(fp)) {
+		SYSLOG((LOG_CRIT, "cannot read login definitions %s [%m]",
+			def_fname));
+		exit(1);
+	}
+
 	(void) fclose(fp);
 }
 
